
def run():
    print("Yep, I'm running!")
    user_in = input("type stop then you want me to stopppppppp")
    if user_in == "stop":
        stop()
    
def stop():
    print("stopped")
    exit()
        
    
    
  


if __name__ == '__main__':
    run()



from setuptools import setup, find_packages

setup(
    name='myproj',
    version='0.1.0_1',
    packages=find_packages(),
    entry_points='''
        [console_scripts]
        myproj=myproj.__main__:run
    ''', 
    license="BSD",  # TODO change the license
    classifiers=[
    ],
    install_requires=[
    ],
    tests_require=[
    ],
)
